AWS_PROFILE = None

# TODO(pcm): This needs to be changed to a more production like URL.
APPLICATION_URL = "http://52.13.36.31:5000"

# Global variable that contains the server session token.
CLI_TOKEN = None
